# In-depth guide to plugin testing

This is the frontpage for the tutorial developed from the [January 2022 workshop on testing](https://youtu.be/IsHYnI8Tbfw?list=PLilvrWT8aLuYID3YZ7KddS5ky2SaH4DKK). This tutorial will be more meaningful to you if you are familiar with the Python programming language and napari software. These lessons summarize the information in the video and should stand on their own. The lessons  are listed here with the timings on the video next to each:  
* 1: [Python’s assert keyword](./1-pythons-assert-keyword.md) - starts at minute [5:23](https://youtu.be/IsHYnI8Tbfw?list=PLilvrWT8aLuYID3YZ7KddS5ky2SaH4DKK&t=333).  
* 2: [Pytest testing framework](./2-pytest-testing-frameworks.md) - starts at minute [9:21](https://youtu.be/IsHYnI8Tbfw?list=PLilvrWT8aLuYID3YZ7KddS5ky2SaH4DKK&t=561).  
* 3: [Readers and fixtures](./3-readers-and-fixtures.md) - starts at minute [15:42](https://youtu.be/IsHYnI8Tbfw?list=PLilvrWT8aLuYID3YZ7KddS5ky2SaH4DKK&t=942).  
* 4: [Test coverage](./4-test-coverage.md) - starts at minute [28:26](https://youtu.be/IsHYnI8Tbfw?list=PLilvrWT8aLuYID3YZ7KddS5ky2SaH4DKK&t=1706).  
* Resource links: [Testing resources](./testing-resources.md)  